llvm_cbuilder
=========

llvm_cbuilder is a set of Python-contexts you can use to write C-like
constructs in Python which generates llvmpy code directly. 

Similar to llpython it allows you to build llvm IR without using the
llvmpy interface directly. 

Look in the llvm_cbuilder tests directory for examples of use.


